pub struct ZwpLockedPointerV1 { /* private fields */ }Expand description
receive relative pointer motion events
The wp_locked_pointer interface represents a locked pointer state.
While the lock of this object is active, the wl_pointer objects of the associated seat will not emit any wl_pointer.motion events.
This object will send the event ‘locked’ when the lock is activated. Whenever the lock is activated, it is guaranteed that the locked surface will already have received pointer focus and that the pointer will be within the region passed to the request creating this object.
To unlock the pointer, send the destroy request. This will also destroy the wp_locked_pointer object.
If the compositor decides to unlock the pointer the unlocked event is sent. See wp_locked_pointer.unlock for details.
When unlocking, the compositor may warp the cursor position to the set cursor position hint. If it does, it will not result in any relative motion events emitted via wp_relative_pointer.
If the surface the lock was requested on is destroyed and the lock is not yet activated, the wp_locked_pointer object is now defunct and must be destroyed.
See also the Event enum for this interface.
Implementations
Sourceimpl ZwpLockedPointerV1
impl ZwpLockedPointerV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the locked pointer object
Destroy the locked pointer object. If applicable, the compositor will unlock the pointer.
Sourcepub fn set_cursor_position_hint(&self, surface_x: f64, surface_y: f64)
pub fn set_cursor_position_hint(&self, surface_x: f64, surface_y: f64)
set the pointer cursor position hint
Set the cursor position hint relative to the top left corner of the surface.
If the client is drawing its own cursor, it should update the position hint to the position of its own cursor. A compositor may use this information to warp the pointer upon unlock in order to avoid pointer jumps.
The cursor position hint is double-buffered state, see wl_surface.commit.
Sourcepub fn set_region(&self, region: Option<&WlRegion>)
pub fn set_region(&self, region: Option<&WlRegion>)
set a new lock region
Set a new region used to lock the pointer.
The new lock region is double-buffered, see wl_surface.commit.
For details about the lock region, see wp_locked_pointer.